import { Client } from '@bilingo.com/ts-linker-sdk';
import { ContactMsg, ContactAddMsg, ChatroomMsg, ConversationTop } from './messages';
export interface WebSocketClientStatus {
    created: boolean;
    connected: boolean;
    login: boolean;
}
export interface WebSocketResp {
    value: object | string;
}
export declare type ListenerCallback = (data: WebSocketResp) => void;
export declare class WebSocketClient {
    client: Client;
    interval: number;
    wsUrl: string;
    token: string;
    sid: string;
    chatToken: object;
    extendOpts: any;
    status: WebSocketClientStatus;
    constructor(wsUrl: string, token: string, sid: string, chatToken: object, extendOpts: any);
    init(): Promise<{}>;
    getStatus(): WebSocketClientStatus;
    create(): Promise<{}>;
    on(url: string, callback: (data: WebSocketResp) => void): void;
    off(url: string): void;
    request(url: string, data: object): Promise<any>;
    connect(): Promise<any>;
    ping(): Promise<any>;
    authentication(): Promise<any>;
    onMessage(callback: ListenerCallback): Promise<void>;
    sendMessage(data: object): Promise<any>;
    markServiced(data: {
        msg_id: string;
    }): Promise<any>;
    messageReaded(data: {
        msg_id: string;
    }): Promise<any>;
    getHistoryMessage(data: {
        contact_id: string;
        chat_type: string;
        start_time: number;
        limit: number;
    }): Promise<any>;
    updateStatus(data: {
        status: 'on' | 'off' | 'busy';
    }): Promise<any>;
    getSessionLists(): Promise<any>;
    getAllConversations(data: {
        last_pull: number;
    }): Promise<any>;
    getAllContact(data: {
        page: number;
        limit: number;
    }): Promise<any>;
    addContact(data: {
        to_add_username: string;
        reason: string;
    }): Promise<any>;
    deleteContact(data: ContactMsg): Promise<any>;
    maskingContact(data: ContactMsg): Promise<any>;
    removeMaskingContact(data: ContactMsg): Promise<any>;
    stickingContact(data: ContactMsg): Promise<any>;
    removeStickContact(data: ContactMsg): Promise<any>;
    setNoDisturbing(data: ContactMsg): Promise<any>;
    removeNoDisturbing(data: ContactMsg): Promise<any>;
    agreeAddContact(data: ContactAddMsg): Promise<any>;
    rejectAddContact(data: ContactAddMsg): Promise<any>;
    addContactServiced(data: ContactAddMsg): Promise<any>;
    createChatroom(data: {
        subject: string;
        description: string;
        welcome_message: string;
        max: number;
    }): Promise<any>;
    destroyChatroom(data: ChatroomMsg): Promise<any>;
    leaveChatroom(data: ChatroomMsg): Promise<any>;
    getChatroomProfile(data: ChatroomMsg): Promise<any>;
    updateChatroomSubject(data: ChatroomMsg): Promise<any>;
    updateChatroomDescription(data: ChatroomMsg): Promise<any>;
    addChatroomAdmin(data: ChatroomMsg): Promise<any>;
    removeChatroomAdmin(data: ChatroomMsg): Promise<any>;
    addChatroomAdmins(data: ChatroomMsg): Promise<any>;
    removeChatroomAdmins(data: ChatroomMsg): Promise<any>;
    joinChatroom(data: {}): Promise<any>;
    removeChatroomMember(data: ChatroomMsg): Promise<any>;
    fetchStickChatroom(data: {
        cache_time: number;
    }): Promise<any>;
    fetchChatroomMembers(data: ChatroomMsg): Promise<any>;
    setConversationIsTop(data: ConversationTop): Promise<any>;
    searchHistoryMessage(data: {
        contact_id: string;
        chat_type: string;
        keyword: string;
        limit: number;
    }): Promise<any>;
    startGroupChat(data: {
        subject: string;
        description?: string;
        contact_list: {
            id: string;
            source: string;
        }[];
        welcome_message?: string;
        group_type: number;
    }): Promise<any>;
}
